pub enum Bound<T> {
Bounded(T),
Unbounded,
}Expand description
An endpoint of an interval of time.
Variants
Bounded(T)
A finite endpoint.
Indicates that there is a bound in this direction.
Unbounded
An infinite endpoint.
Indicates that there is no bound in this direction.