Relation

Enum Relation 

pub enum Relation {
    Precedes {
        is_inverted: bool,
    },
    Meets {
        is_inverted: bool,
    },
    Overlaps {
        is_inverted: bool,
    },
    Finishes {
        is_inverted: bool,
    },
    Contains {
        is_inverted: bool,
    },
    Starts {
        is_inverted: bool,
    },
    Equals,
}
A type describing the possible relations between two intervals (e.g. s and t).

The relations are comparable (via Ord) by the degree to which s begins before t and then within that by the degree to which s ends before t.

Six pairs of the relations are converses. For example, the converse of “s precedes t” is “t is preceded by s”; whenever the first relation is true, its converse is true also. The thirteenth, “s equals t”, is its own converse

Variants



Precedes

Precedes { is_inverted: false }:

s: ┌────────┐
t:            └────────┘

Precedes { is_inverted: true }:

s:            ┌────────┐
t: └────────┘

Fields

is_inverted: bool

true iff the relation is inverted, otherwise `false.

  • false => “s precedes t”
  • true => “s is preceded by t”


Meets

Meets { is_inverted: false }:

s: ┌────────┐
t:          └────────┘

Meets { is_inverted: true }:

s:          ┌────────┐
t: └────────┘

Fields

is_inverted: bool

true iff the relation is inverted, otherwise `false.

  • false => “s meets t”
  • true => “s is met by t”


Overlaps

Overlaps { is_inverted: false }:

s: ┌────────┐
t:      └────────┘

Overlaps { is_inverted: true }:

s:      ┌────────┐
t: └────────┘

Fields

is_inverted: bool

true iff the relation is inverted, otherwise `false.

  • false => “s overlaps t”
  • true => “s is overlapped by t”


Finishes

Finishes { is_inverted: false }:

s:         ┌────────┐
t: └────────────────┘

`Finishes { is_inverted: true }`:

```plain
s: ┌────────────────┐
t:         └────────┘

Fields

is_inverted: bool

true iff the relation is inverted, otherwise `false.

  • false => “s finishes t”
  • true => “s is finished by t”


Contains

Contains { is_inverted: false }:

s: ┌────────────────┐
t:     └────────┘

Contains { is_inverted: true }:

s:     ┌────────┐
t: └────────────────┘

Fields

is_inverted: bool

true iff the relation is inverted, otherwise `false.

  • false => “s contains t”
  • true => “s is contained by t”


Starts

Starts { is_inverted: false }:

s: ┌────────┐
t: └────────────────┘

Starts { is_inverted: true }:

s: ┌────────────────┐
t: └────────┘

Fields

is_inverted: bool

true iff the relation is inverted, otherwise `false.

  • false => “s starts t”
  • true => “s is started by t”


Equals

Equals:

s: ┌────────┐
t: └────────┘

Implementations

Source

impl Relation

pub fn as_converse(&self) -> Self

Returns the relation’s converse.