pub struct Interval<T> {
pub start: T,
pub end: T,
}Expand description
A (half-open) interval bounded inclusively below and either exclusively or inclusively above.
- exclusively above (
start..end) in discrete domains. - inclusively above (
start..=end) in continuous domains.
The interval Interval { start, end } contains all values with start <= x < end,
if T is a discrete domain, or start <= x <= end, if T is a continuous domain.
It is empty if start >= end, if T is a discrete domain,
or start > end if T is a continuous domain.
Fields
start: TThe lower bound of the interval (inclusive).
end: TThe upper bound of the interval (exclusive, or inclusive).