IntervalTo

Struct IntervalTo 

pub struct IntervalTo<T> {
    pub end: T,
}
An interval only bounded exclusively, or inclusively above (..end, or ..=end).

The RangeTo ..end contains all values with x < end, if T is a discrete domain, or x <= end, if T is a continuous domain.

Fields

end: T

The upper bound of the interval (exclusive, or inclusive).