NonEmpty

Struct NonEmpty 

pub struct NonEmpty<T>(/* private fields */);
An interval that is known not to be empty.

Layout

NonEmpty<T> is guaranteed to have the same layout and bit validity as T with the exception that non-empty instances are valid.

Implementations

Source

impl<T> NonEmpty<T>

pub unsafe fn new_unchecked(value: T) -> Self

Creates a non-empty without checking whether the value is non-empty. This results in undefined behavior if the value is empty.

Safety

The value must not be empty.